@@ -1,5 +1,6 @@
 use std::fmt::*;
 use std::fs::{self, File};
+use std::path::Path;
 
 use crate::timer::*;
 use colored::Colorize;
@@ -15,7 +16,8 @@ pub fn create_file(path: String) -> Option<File> {
         }
     };
     if let Some(str_temp) = get_local_time() {
-        let path_temp = get_file_path(path, str_temp, crate::FILE_SUF.to_string());
+        let str_temp = get_file_path(path, str_temp, crate::FILE_SUF.to_string());
+        let path_temp = Path::new(&str_temp);
         let a = fs::OpenOptions::new()
             .write(true)
             .read(true)
@@ -40,5 +42,6 @@ pub fn create_file(path: String) -> Option<File> {
 
 // 文件路径拼接
 fn get_file_path(path: String, file_name: String, file_suf: String) -> String {
+    let file_name = file_name.replace(":", "-");
     format(format_args!("{}/{}.{}", path, file_name, file_suf))
 }
